about summary refs log tree commit diff
diff options
context:
space:
mode:
-rw-r--r--src/build-remote/build-remote.cc2
-rw-r--r--src/libstore/optimise-store.cc4
2 files changed, 3 insertions, 3 deletions
diff --git a/src/build-remote/build-remote.cc b/src/build-remote/build-remote.cc
index 8719959f0b..7455160c73 100644
--- a/src/build-remote/build-remote.cc
+++ b/src/build-remote/build-remote.cc
@@ -57,7 +57,7 @@ int main (int argc, char * * argv)
         settings.builders = argv[5];
 
         /* It would be more appropriate to use $XDG_RUNTIME_DIR, since
-           that gets cleared on reboot, but it wouldn't work on OS X. */
+           that gets cleared on reboot, but it wouldn't work on macOS. */
         currentLoad = settings.nixStateDir + "/current-load";
 
         std::shared_ptr<Store> sshStore;
diff --git a/src/libstore/optimise-store.cc b/src/libstore/optimise-store.cc
index 8e8002a30d..ba1ebc370f 100644
--- a/src/libstore/optimise-store.cc
+++ b/src/libstore/optimise-store.cc
@@ -98,14 +98,14 @@ void LocalStore::optimisePath_(OptimiseStats & stats, const Path & path, InodeHa
         throw SysError(format("getting attributes of path ‘%1%’") % path);
 
 #if __APPLE__
     /* HFS/OS X has some undocumented security feature disabling hardlinking for
        special files within .app dirs. *.app/Contents/PkgInfo and
        *.app/Contents/Resources/\*.lproj seem to be the only paths affected. See
        https://github.com/NixOS/nix/issues/1443 for more discussion. */
 
     if (std::regex_search(path, std::regex("\\.app/Contents/PkgInfo$")) ||
         std::regex_search(path, std::regex("\\.app/Contents/Resources/.+\\.lproj$"))) {
-        debug(format("‘%1%’ is not allowed to be linked in OS X") % path);
+        debug(format("‘%1%’ is not allowed to be linked in macOS") % path);
         return;
     }
 #endif
@@ -98,14 +98,14 @@ void LocalStore::optimisePath_(OptimiseStats & stats, const Path & path, InodeHa
 
 #if __APPLE__
-    /* HFS/OS X has some undocumented security feature disabling hardlinking for
+    /* HFS/macOS has some undocumented security feature disabling hardlinking for
        special files within .app dirs. *.app/Contents/PkgInfo and
        *.app/Contents/Resources/\*.lproj seem to be the only paths affected. See